@@ -21,7 +21,7 @@
 
 /*
  * cursor.c - defines the cursor object DBAPI 2.0
- * $Id: cursor.c,v 1.109.2.21 2004/05/16 08:24:55 fog Exp $
+ * $Id: cursor.c,v 1.109.2.24 2004/07/29 21:52:38 fog Exp $
  */
 
 #ifdef _WIN32
@@ -51,6 +51,8 @@
 void
 pgconn_notice_callback(void *args, const char *message)
 {
+    if (strncmp(message, "ERROR", 5) == 0)
+        PyErr_SetString(ProgrammingError, message);
     Dprintf("%s\n", message);
 }
 
@@ -775,6 +777,10 @@ _psyco_curs_execute(cursobject *self, char *query,
         
         /* call the callback */
         res = cb(self, cb_args);
+        if (PyErr_Occurred()) {
+            Py_XDECREF(res);
+            goto error;
+        }
         break;
 
         /* tuples, this was a select */
@@ -914,8 +920,8 @@ _psyco_curs_execute(cursobject *self, char *query,
         /* ok but no tuples */
     case PGRES_COMMAND_OK:
         Dprintf("_psyco_curs_execute: command returned OK (no tuples)\n");
-        /* sets rowcount from PQcmdTuples as an extra check */
-        self->rowcount = atoi(PQcmdTuples(self->pgres));
+        /* sets rowcount to the right number of affected tuples */
+        self->rowcount = PQntuples(self->pgres);
         /* try to obtain the oid of an insert */
         self->last_oid = PQoidValue(self->pgres);
 
@@ -1012,7 +1018,6 @@ _mogrify(PyObject *var, PyObject *fmt, PyObject **new)
             if (*d == ')') {
                 key = PyString_FromStringAndSize(c+2, d-c-2);
                 value = PyObject_GetItem(var, key);
-                Dprintf("_mogrify: value refcnt: %d\n", value->ob_refcnt);
                 /* key has refcnt 1, value the original value + 1 */
                 
                 /*  if value is NULL this is not a dictionary or the key
@@ -1023,6 +1028,8 @@ _mogrify(PyObject *var, PyObject *fmt, PyObject **new)
                     return -1;
                 }
 
+                Dprintf("_mogrify: value refcnt: %d\n", value->ob_refcnt);
+                
                 if (n == NULL) {
                     n = PyDict_New();
                 }
@@ -1368,6 +1375,8 @@ psyco_curs_executemany(cursobject *self, PyObject *args)
         }
     }
 
+    self->rowcount = -1;
+    
     Py_DECREF(tmpobj);
     Py_DECREF(parm_seq);
     Py_INCREF(Py_None);
@@ -1707,8 +1716,13 @@ static char psyco_curs_setoutputsizes__doc__[] =
 static PyObject *
 psyco_curs_setoutputsize(cursobject *self, PyObject *args)
 {
-    PARSEARGS(args);
+    long int size, column;
+
+    if (!PyArg_ParseTuple(args, "l|l", &size, &column))
+        return NULL;
+
     EXC_IFCLOSED(self);
+    
     Py_INCREF(Py_None);
     return Py_None;
 }
@@ -1950,13 +1964,6 @@ psyco_curs_copy_from(cursobject *self, PyObject *args)
     
     res = _psyco_curs_execute(self, query, _psyco_curs_copy_from, file);
     free(query);
-
-    
-    if (res == NULL)
-    {
-        PyErr_SetString(ProgrammingError, "copy_from() failed");
-        return NULL;
-    }
     
     return res;
 }
