@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2001 Michele Comitini <mcm@initd.net>
- * Copyright (C) 2001 Federico Di Gregorio <fog@debian.org>
+ * Copyright (C) 2001-2003 Federico Di Gregorio <fog@debian.org>
  *
  * This file is part of the psycopg module.
  *
@@ -21,11 +21,9 @@
 
 /*
  * module.c -- defines the module interface to DBAPI 2.0
- * $Id: module.c,v 1.41 2003/02/25 21:44:08 fog Exp $
+ * $Id: module.c,v 1.41.2.3 2004/01/16 23:24:20 fog Exp $
  */
 
-#include <time.h>
-
 #ifdef _WIN32
 #include "config32.h"
 #else
@@ -36,12 +34,8 @@
 #include "typeobj.h"
 #include "typemod.h"
 
-/* included after pthread.h to work on MacOS X */
-#include <Python.h>
-#include <structmember.h>
 #include <string.h>
 
-
 /**** MODULE FUNCTIONS ****/
 
 /* psyco_connect() - create a new connection */
@@ -64,14 +58,15 @@ psyco_connect(PyObject *self, PyObject *args, PyObject *keywds)
     PyObject *conn;
     int maxconn=MAXCONN, minconn=MINCONN, serialize=1, idsn=-1;
     char *dsn=NULL, *database=NULL, *user=NULL, *password=NULL,
-         *host=NULL, *port=NULL;
+         *host=NULL, *port=NULL, *sslmode=NULL;
+    
     static char *kwlist[] = {"dsn", "database", "host", "port",
-                             "user", "password", 
+                             "user", "password", "sslmode", 
                              "maxconn", "minconn", "serialize", NULL};
 
-    if (!PyArg_ParseTupleAndKeywords(args, keywds, "|ssssssiii", kwlist,
+    if (!PyArg_ParseTupleAndKeywords(args, keywds, "|sssssssiii", kwlist,
                                      &dsn, &database, &host, &port,
-                                     &user, &password, 
+                                     &user, &password, &sslmode,
                                      &maxconn, &minconn, &serialize)) {
         return NULL;
     }
@@ -83,7 +78,8 @@ psyco_connect(PyObject *self, PyObject *args, PyObject *keywds)
         if (port) l += strlen(port);
         if (user) l += strlen(user);
         if (password) l += strlen(password);
-
+        if (sslmode) l += strlen(sslmode);
+        
         dsn = malloc(l*sizeof(char));
         if (dsn == NULL) {
             PyErr_SetString(InterfaceError, "dynamic dsn allocation failed");
@@ -111,6 +107,10 @@ psyco_connect(PyObject *self, PyObject *args, PyObject *keywds)
             strcpy(&dsn[idsn], " password="); idsn += 10;
             strcpy(&dsn[idsn], password); idsn += strlen(password);
         }
+        if (sslmode) {
+            strcpy(&dsn[idsn], " sslmode="); idsn += 9;
+            strcpy(&dsn[idsn], sslmode); idsn += strlen(sslmode);
+        }
 
         if (idsn > 0) {
             dsn[idsn] = '\0';
@@ -214,7 +214,8 @@ initpsycopg(void)
     Dprintf("initpsycopg: module initialized\n");
     
     /* DBAPI compliance module parameters */
-    PyDict_SetItemString(d, "__version__", PyString_FromString(VERSION));
+    PyDict_SetItemString(d, "__version__",
+                         PyString_FromString(PACKAGE_VERSION));
     PyDict_SetItemString(d, "apilevel", PyString_FromString(APILEVEL));
     PyDict_SetItemString(d, "threadsafety", PyInt_FromLong(THREADSAFETY));
     PyDict_SetItemString(d, "paramstyle", PyString_FromString(PARAMSTYLE));
