@@ -20,7 +20,7 @@
 
 /*
  * typemod.c -- types available to the psycopg module
- * $Id: typemod.c,v 1.13.2.2 2003/11/20 23:53:46 fog Exp $
+ * $Id: typemod.c,v 1.13.2.3 2004/07/29 21:52:38 fog Exp $
  */
 
 #include "module.h"
@@ -360,9 +360,11 @@ psyco_QuotedStringObject_getattr(psyco_BufferObject *self, char *name)
 static void
 psyco_QuotedStringObject_destroy(psyco_QuotedStringObject *self)
 {
+    Dprintf("psyco_QuotedStringObject_destroy: "
+            "self->buffer->refcnt = %d\n", self->buffer->ob_refcnt);
     Py_DECREF(self->buffer);
     PyObject_Del(self);
-    Dprintf("psyco_QuotedStringObject_destroy(): "
+    Dprintf("psyco_QuotedStringObject_destroy: "
             "quotedstringobject at %p destroyed\n", self);
 }
 
@@ -631,8 +633,6 @@ psyco_Binary(PyObject *self, PyObject *args)
 
     if (!PyArg_ParseTuple(args, "O!", &PyString_Type, &str))
         return NULL;
-
-    Py_INCREF(str);
     return new_psyco_bufferobject(str);
 }
 
@@ -643,8 +643,6 @@ psyco_QuotedString(PyObject *self, PyObject *args)
 
     if (!PyArg_ParseTuple(args, "O!", &PyString_Type, &str))
         return NULL;
-
-    Py_INCREF(str);
     return new_psyco_quotedstringobject(str);
 }
 
