@@ -20,7 +20,7 @@
 
 /*
  * typeobj.c -- define the type objects
- * $Id: typeobj.c,v 1.24.2.3 2004/05/16 08:09:49 fog Exp $
+ * $Id: typeobj.c,v 1.24.2.5 2004/07/29 21:52:38 fog Exp $
  */
 
 #include "module.h"
@@ -196,7 +196,7 @@ psyco_INTERVAL_cast(PyObject *s)
 
         case ':':
             if (part <= 3) {
-                hours = v*sign;
+                hours = v;
                 Dprintf("psyco_INTERVAL_cast(): hours = %f\n", hours);
                 v = 0.0; part = 4;
             }
@@ -239,8 +239,8 @@ psyco_INTERVAL_cast(PyObject *s)
     }
     
     /* calculates seconds */
-    if (hours < 0.0 || hours == -0.0) {
-        seconds = - (hundredths + seconds + minutes*60) + hours*3600;
+    if (sign < 0.0) {
+        seconds = - (hundredths + seconds + minutes*60 + hours*3600);
     }
     else {
         seconds += hundredths + minutes*60 + hours*3600;
